@@ -1286,7 +1286,7 @@ class Script(default.Script):
             if self.getLinkIndex(obj, i) >= 0:
                 voice = voices[settings.HYPERLINK_VOICE]
                 break
-            elif word.isupper():
+            elif word.decode("UTF-8").isupper():
                 voice = voices[settings.UPPERCASE_VOICE]
             else:
                 voice = voices[settings.DEFAULT_VOICE]
@@ -1912,6 +1912,16 @@ class Script(default.Script):
             handleEvent = True
             presentEvent = False
 
+        if orca_state.locusOfFocus \
+           and self.isSameObject(orca_state.locusOfFocus, event.any_data):
+            # We're already on the new item. If we (or the default script)
+            # presents it, the speech.stop() will cause us to interrupt the
+            # presentation we're probably about to make due to an earlier
+            # event.
+            #
+            handleEvent = True
+            presentEvent = False
+
         if handleEvent:
             if presentEvent:
                 speech.stop()
@@ -2309,7 +2319,7 @@ class Script(default.Script):
         if isinstance(orca_state.lastInputEvent,
                         input_event.MouseButtonEvent) and \
              orca_state.lastInputEvent.button == "2":
-            if text.isupper():
+            if text.decode("UTF-8").isupper():
                 speech.speak(text, self.voices[settings.UPPERCASE_VOICE])
             else:
                 speech.speak(text)
